summaryrefslogtreecommitdiffstats
path: root/chrome/browser/ui/cocoa/dev_tools_controller.h
diff options
context:
space:
mode:
authorthakis@chromium.org <thakis@chromium.org@0039d316-1c4b-4281-b951-d872f2087c98>2012-01-23 18:08:17 +0000
committerthakis@chromium.org <thakis@chromium.org@0039d316-1c4b-4281-b951-d872f2087c98>2012-01-23 18:08:17 +0000
commitb7a756d47f9b8295729d21a2a0d5ed8582da4e8f (patch)
tree4ae68bf009d359ce85edcee27f1026becbcc384b /chrome/browser/ui/cocoa/dev_tools_controller.h
parent545dd93c61b3c0ce100b628a11d920fab19fe9b0 (diff)
downloadchromium_src-b7a756d47f9b8295729d21a2a0d5ed8582da4e8f.zip
chromium_src-b7a756d47f9b8295729d21a2a0d5ed8582da4e8f.tar.gz
chromium_src-b7a756d47f9b8295729d21a2a0d5ed8582da4e8f.tar.bz2
Change grow box computation back to a method on BrowserWindow
This is a revert of http://codereview.chromium.org/3547008, which was added to implement sidebars. aa has reverted most of the sidebar code ( http://codereview.chromium.org/9006027/ ), so this is no longer needed. This not only makes the code simpler (look at all the red), but also fixes a long-standing regression on Mac that was caused by the CL this reverts. Parts of the windows part with help form sky@. This does not add back the code in rwhv_win that was added by mad@ for bug 458, since it has since then bitrotted, and it's not used anyway. If someone wants to attack 458 again, http://codereview.chromium.org/16488/diff/1101/chrome/browser/renderer_host/render_widget_host_view_win.cc should be fairly easy to add back. BUG=458,70482,107646 TEST=Not too much stuff breaks; resize box looks good again on 10.5/10.6 TBR=avi Review URL: http://codereview.chromium.org/9265018 git-svn-id: svn://svn.chromium.org/chrome/trunk/src@118700 0039d316-1c4b-4281-b951-d872f2087c98
Diffstat (limited to 'chrome/browser/ui/cocoa/dev_tools_controller.h')
-rw-r--r--chrome/browser/ui/cocoa/dev_tools_controller.h20
1 files changed, 7 insertions, 13 deletions
diff --git a/chrome/browser/ui/cocoa/dev_tools_controller.h b/chrome/browser/ui/cocoa/dev_tools_controller.h
index f4fa57f..95f2992 100644
--- a/chrome/browser/ui/cocoa/dev_tools_controller.h
+++ b/chrome/browser/ui/cocoa/dev_tools_controller.h
@@ -1,4 +1,4 @@
-// Copyright (c) 2011 The Chromium Authors. All rights reserved.
+// Copyright (c) 2012 The Chromium Authors. All rights reserved.
// Use of this source code is governed by a BSD-style license that can be
// found in the LICENSE file.
@@ -10,16 +10,18 @@
#import "base/mac/cocoa_protocols.h"
#include "base/memory/scoped_nsobject.h"
-#import "chrome/browser/ui/cocoa/tab_contents/tab_contents_controller.h"
@class NSSplitView;
@class NSView;
class Profile;
-class TabContents;
+
+namespace content {
+class WebContents;
+}
// A class that handles updates of the devTools view within a browser window.
// It swaps in the relevant devTools contents for a given TabContents or removes
// the view, if there's no devTools contents to show.
@interface DevToolsController : NSObject<NSSplitViewDelegate> {
@private
@@ -27,12 +29,9 @@ class TabContents;
scoped_nsobject<NSSplitView> splitView_;
BOOL dockToRight_;
-
- // Manages currently displayed devTools contents.
- scoped_nsobject<TabContentsController> contentsController_;
}
-- (id)initWithDelegate:(id<TabContentsControllerDelegate>)delegate;
+- (id)init;
// This controller's view.
- (NSView*)view;
@@ -50,11 +49,6 @@ class TabContents;
// Specifies whether devtools should dock to right.
- (void)setDockToRight:(BOOL)dock_to_right
withProfile:(Profile*)profile;
-
-// Call when the devTools view is properly sized and the render widget host view
-// should be put into the view hierarchy.
-- (void)ensureContentsVisible;
-
@end
#endif // CHROME_BROWSER_UI_COCOA_DEV_TOOLS_CONTROLLER_H_
@@ -10,16 +10,18 @@
// A class that handles updates of the devTools view within a browser window.
-// It swaps in the relevant devTools contents for a given TabContents or removes
+// It swaps in the relevant devTools contents for a given WebContents or removes
// the view, if there's no devTools contents to show.